Citing exSpy
************

**exSpy** is maintained by the exSpy community
<https://github.com/hyperspy/exspy/contributors>`_.

If exSpy has been significant to a project that leads to an academic
publication, please acknowledge that fact by citing it. The DOI in the
badge below is the `Concept DOI <https://help.zenodo.org/faq/#versioning>`_ --
it can be used to cite the project without referring to a specific
version. If you are citing HoloSpy because you have used it to process data,
please use the DOI of the specific version that you have employed. You can
find it by clicking on the DOI badge below:

To be updated after first release.
